Utilities
=========

This includes various utilities to help in optimization. In the future,
parameter search and plotting techniques will be incoroporated in this
module.

.. toctree::

   pyswarms.utils.functions
   pyswarms.utils.search
